Package: rDEA
Version: 1.2-8
Title: Robust Data Envelopment Analysis (DEA) for R
Description: Data Envelopment Analysis for R, estimating robust DEA scores without and with environmental variables and doing returns-to-scale tests.
Authors@R: c(person("Jaak", "Simm", role = c("aut", "cre"), email = "jaak.simm@gmail.com"), person("Galina", "Besstremyannaya", role = c("aut") ))
Imports: slam (>= 0.1-9), truncreg(>= 0.2-1), truncnorm(>= 1.0-7),
        maxLik
Suggests: testthat
SystemRequirements: GLPK (>= 4.52)
License: GPL-2 | GPL-3
URL: https://github.com/jaak-s/rDEA
LazyData: true
Packaged: 2023-06-28 10:49:51 UTC; jaak
Maintainer: Jaak Simm <jaak.simm@gmail.com>
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2023-06-29 15:00:02 UTC
Author: Jaak Simm [aut, cre],
  Galina Besstremyannaya [aut]
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 12:00:19 UTC; unix
Archs: rDEA.so.dSYM
